@@ -3,6 +3,18 @@
 #later when I want 'global' variables in the rgsepd code, theyll be stored under pkg_globals
 pkg_globals <- new.env();
 
+
+# the hash table package is going away in 2022 and we need to replace its functionality
+hash <- function(keys, values){
+  ht1 <- new.env(hash=TRUE)
+  stopifnot(length(keys) == length(values))
+  for(j in 1:length(keys)){
+    ht1[[keys[j]]] <- values[j]
+  }
+  ht1
+}
+
+
 .onAttach <- function(libname, pkgname) {
   packageStartupMessage(sprintf("Loading R/GSEPD %s",packageDescription("rgsepd")$Version))
   packageStartupMessage("Building human gene name caches")
@@ -11,6 +23,8 @@ pkg_globals <- new.env();
   # http://stackoverflow.com/questions/12598242/global-variables-in-packages-in-r
   #assign("pkg_globals", new.env(), envir=parent.env(environment()))
 
+
+  
   RefSeqs <- grep("^N[MR]_",
                   AnnotationDbi::keys(org.Hs.eg.db,keytype="REFSEQ"),
                   value=TRUE)
@@ -138,11 +152,11 @@ LocalDB_Lookup <- function(res)
 
 
 biomaRt_Lookup <- function(res) {  
-
+  message("Converting identifiers with biomart");
   #now subset the table to those we didn't know yet.
   gns=unique( subset(res,is.na(res$ENTREZ))$id)
   #listMarts(host="www.ensembl.org")
-  ensembl = useMart("ENSEMBL_MART_ENSEMBL", host="www.ensembl.org")
+  ensembl = useMart("ENSEMBL_MART_ENSEMBL", host="https://www.ensembl.org")
   ensembl = useDataset("hsapiens_gene_ensembl",mart=ensembl)
   attrs=listAttributes(ensembl)
   aa=c("refseq_mrna" , "chromosome_name" , "start_position" ,  "end_position" ,
@@ -197,7 +211,7 @@ AnnotateTable <- function(G){
   message("dropping rows with raw PVAL>0.990 OR baseMean < 1 OR on excludes list")
   res=subset(res,res$pval <= 0.990 & res$baseMean >= 1 & !(res$id %in% G$EXCLUDES))
   res$id = sub(" +$", "", res$id)
-  message(paste("Rows remaining:",length(res$id)));
+  message(paste("deseq txid rows remaining:",length(res$id)));
   if(length(unique(res$id)) < 1){
     warning("AnnotateTable : no rows significant enough to annotate.  Quitting table re-gen.");
     return();
@@ -206,11 +220,14 @@ AnnotateTable <- function(G){
   message("Converting identifiers with local DB");
   res<-LocalDB_Lookup(res);
   #and the rest
-  message("Converting identifiers with biomart");
   #fix strings?
   res$ENTREZ <- as.character(res$ENTREZ)
   res$HGNC <- as.character(res$HGNC)
   
+  # in 2022 Ensembl is giving warning messages about https
+  # and https is giving error messages on ubuntu or cluster environments
+  # we can omit the biomart calls and get our results more reliably. 
+  if(FALSE){
    res = tryCatch({
      biomaRt_Lookup(res)
    }, warning = function(w) {
@@ -220,6 +237,8 @@ AnnotateTable <- function(G){
      warning(e) #if bioMart is down, just keep moving.
      res
    })
+  }
+   
   res<-subset(res,select=c("id","baseMean","baseMeanA","baseMeanB","foldChange","log2FoldChange","lfcSE","pval","padj","HGNC","ENTREZ"))
   columns = c("REFSEQ","baseMean",C2T[1],C2T[2],"(X/Y)","LOG2(X/Y)","lfcSE","PVAL","PADJ","HGNC","ENTREZ");
   if(!G$QUIET)Message_Generate(outfile)
@@ -245,15 +264,18 @@ AnnotateTable.GO <- function(G){
   
   #default hard filtering:
   DEG=ifelse(  sdata$PADJ < G$LIMIT$PADJ  &
-               sdata$baseMean >= G$LIMIT$baseMean &
-               abs(sdata$LOG2.X.Y.) >= G$LIMIT$LFC, 1,0)
+                sdata$baseMean >= G$LIMIT$baseMean &
+                abs(sdata$LOG2.X.Y.) >= G$LIMIT$LFC,
+               1,0)
   
   #but if we're not set to HARD mode, and we got only a handful of genes:
   if( !(G$LIMIT$HARD) && sum(DEG)<(0.075*length(DEG))){
-    ToLevel=round((0.075*nrow(sdata)))
+    ToLevel = round((0.075*nrow(sdata)))
     PThresh = sort(sdata$PVAL,decreasing=FALSE)[ToLevel]
-    DEG=ifelse(sdata$PVAL < PThresh , 1,0)
-    message(sprintf("Not many genes found differentially expressed, (re)moving the filters to raw p=%f so we can use %d genes with GOSEQ.",PThresh,sum(DEG)))
+    DEG = ifelse(sdata$PVAL < PThresh , 1,0)
+    message( sprintf(
+"Not many genes found differentially expressed, (re)moving the filters to raw p=%g so we can use %d genes with GOSEQ.",
+                    PThresh,sum(DEG)))
   }
   if(sum(DEG)<2){
     stop("I can't do pathways or GO terms when so few genes pass significance. Try changing your G$LIMIT parameters.")
@@ -303,8 +325,10 @@ AnnotateTable.GO <- function(G){
   
   FilterGOSEQ <- function(GOR, PLIM) {
     # do a Benjamini-Hochberg correction of p-values.
-    GOR$over_represented_padj = p.adjust(GOR$over_represented_pvalue, method="BH")
-    GOR$under_represented_padj = p.adjust(GOR$under_represented_pvalue, method="BH")
+    GOR$over_represented_padj = p.adjust(GOR$over_represented_pvalue,
+                                         method=as.character(G$LIMIT$goseq_padj_method))
+    GOR$under_represented_padj = p.adjust(GOR$under_represented_pvalue,
+                                          method=as.character(G$LIMIT$goseq_padj_method))
     #filter reported set to something with a pvalue:
     GOR$minp <- apply(cbind( 
       GOR$over_represented_padj , GOR$under_represented_padj),
